document.addEventListener('DOMContentLoaded', () => {
  const dropZone = document.getElementById('dropZone');
  const fileInput = document.getElementById('fileInput');
  const resultContainer = document.querySelector('.result-container');
  const textOutput = document.getElementById('textOutput');
  const copyBtn = document.getElementById('copyBtn');
  const downloadBtn = document.getElementById('downloadBtn');

  // Drag and drop handlers
  ['dragenter', 'dragover', 'dragleave', 'drop'].forEach(eventName => {
    dropZone.addEventListener(eventName, preventDefaults, false);
    document.body.addEventListener(eventName, preventDefaults, false);
  });

  ['dragenter', 'dragover'].forEach(eventName => {
    dropZone.addEventListener(eventName, highlight, false);
  });

  ['dragleave', 'drop'].forEach(eventName => {
    dropZone.addEventListener(eventName, unhighlight, false);
  });

  dropZone.addEventListener('drop', handleDrop, false);
  fileInput.addEventListener('change', handleFileSelect, false);
  dropZone.addEventListener('click', () => fileInput.click());

  copyBtn.addEventListener('click', copyText);
  downloadBtn.addEventListener('click', downloadText);

  function preventDefaults(e) {
    e.preventDefault();
    e.stopPropagation();
  }

  function highlight(e) {
    dropZone.classList.add('highlight');
  }

  function unhighlight(e) {
    dropZone.classList.remove('highlight');
  }

  function handleDrop(e) {
    const dt = e.dataTransfer;
    const files = dt.files;
    handleFiles(files);
  }

  function handleFileSelect(e) {
    const files = e.target.files;
    handleFiles(files);
  }

  function handleFiles(files) {
    if (files.length === 0) return;
    
    const file = files[0];
    if (file.type !== 'application/pdf') {
      alert('Please upload a PDF file');
      return;
    }

    // Here you would normally use a PDF parsing library
    // Since we're not using external dependencies, we'll just simulate the conversion
    simulateConversion(file);
  }

  function simulateConversion(file) {
    const reader = new FileReader();
    reader.onload = function(e) {
      // Simulate processing time
      setTimeout(() => {
        resultContainer.hidden = false;
        textOutput.textContent = `Simulated conversion of ${file.name}\n\n` +
          'This is a demonstration. In a real implementation, you would need a PDF parsing library ' +
          'or backend service to actually convert the PDF content to text.';
      }, 1000);
    };
    reader.readAsArrayBuffer(file);
  }

  function copyText() {
    navigator.clipboard.writeText(textOutput.textContent)
      .then(() => {
        const originalText = copyBtn.textContent;
        copyBtn.textContent = 'Copied!';
        setTimeout(() => copyBtn.textContent = originalText, 2000);
      })
      .catch(err => console.error('Failed to copy text:', err));
  }

  function downloadText() {
    const blob = new Blob([textOutput.textContent], { type: 'text/plain' });
    const url = window.URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = 'converted-text.txt';
    document.body.appendChild(a);
    a.click();
    window.URL.revokeObjectURL(url);
    document.body.removeChild(a);
  }
});
